pub struct ChangeAddressGenerator { /* private fields */ }Expand description
Change address generator for Silent Payments.
When sending a Silent Payment, the sender may need to create a change output back to themselves. This module provides utilities for generating deterministic change addresses.
Implementations
Sourceimpl ChangeAddressGenerator
impl ChangeAddressGenerator
Sourcepub fn new(
scan_privkey: &[u8; 32],
spend_privkey: &[u8; 32],
network: Network,
) -> Result<Self>
pub fn new( scan_privkey: &[u8; 32], spend_privkey: &[u8; 32], network: Network, ) -> Result<Self>
Create a new change address generator.
Sourcepub fn address(&self) -> Result<SilentPaymentAddress>
pub fn address(&self) -> Result<SilentPaymentAddress>
Get the Silent Payment address for this wallet.